@@ -6,7 +6,7 @@ subst - Greple module for text search and substitution
 
 =head1 VERSION
 
-Version 2.19
+Version 2.20
 
 =head1 SYNOPSIS
 
@@ -15,7 +15,7 @@ greple -Msubst --dict I<dictionary> [ options ]
   --dict      dictionary file
   --dictdata  dictionary data
 
-  --check=[ng,ok,any,outstand,all]
+  --check=[ng,ok,any,outstand,all,none]
   --select=N
   --linefold
   --stat
@@ -31,11 +31,11 @@ greple -Msubst --dict I<dictionary> [ options ]
 
 =head1 DESCRIPTION
 
-This B<greple> module supports check and substitution of text file
-using a dictionary file.
+This B<greple> module supports check and substitution of text files
+based on dictionary data.
 
-Dictionary file is given by B<--dict> option and contains pattern and
-expected string pairs.
+Dictionary file is given by B<--dict> option and each line contains
+pattern and expected string pairs.
 
     greple -Msubst --dict DICT
 
@@ -44,10 +44,10 @@ If the dictionary file contains following data:
     colou?r      color
     cent(er|re)  center
 
-Then above command find the first pattern which does not match the
-second string, that is "colour" and "centre" in this case.
+above command find the first pattern which does not match the second
+string, that is "colour" and "centre" in this case.
 
-Field "//" in dictionary file is ignored, so this file can be written
+Field "//" in dictionary data is ignored, so this file can be written
 like this:
 
     colou?r      //  color
@@ -260,13 +260,15 @@ L<https://www.jtf.jp/jp/style_guide/pdf/jtf_style_guide.pdf>
 L<https://www.microsoft.com/ja-jp/language/styleguides>,
 L<https://www.atmarkit.co.jp/news/200807/25/microsoft.html>
 
+L<https://qiita.com/kaz-utashiro/items/85add653a71a7e01c415>
+
 =head1 AUTHOR
 
 Kazumasa Utashiro
 
 =head1 LICENSE
 
-Copyright (C) 2017-2020 Kazumasa Utashiro.
+Copyright 2017-2021 Kazumasa Utashiro.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -277,7 +279,7 @@ it under the same terms as Perl itself.
 use v5.14;
 package App::Greple::subst;
 
-our $VERSION = '2.19';
+our $VERSION = '2.20';
 
 use warnings;
 use utf8;
@@ -308,18 +310,6 @@ use App::Greple::subst::Dict;
 use File::Share qw(:all);
 $ENV{GREPLE_SUBST_DICT} //= dist_dir 'App-Greple-subst';
 
-package App::Greple::subst::SmartString {
-    use List::Util qw(any);
-    sub new {
-	my($class, $var) = @_;
-	bless ref $var ? $var : \$var, $class;
-    }
-    sub is {
-	my $obj = shift;
-	any { $_ eq $$obj } @_;
-    }
-}
-
 our $debug = 0;
 our $remember_data = 1;
 our $opt_subst = 0;
@@ -807,11 +797,11 @@ autoload -Msubst::dyncmap --dyncmap
 
 help	--subst-color-light light terminal color
 option	--subst-color-light --colormap --dyncmap \
-	range=0-2,except=000:111:222,shift=3,even="555D/%s",odd="I;000/%s"
+	range=0-2,except=000:111:222,shift=3,even="555D/%s",odd="IU;000/%s"
 
 help	--subst-color-dark dark terminal color
 option	--subst-color-dark --colormap --dyncmap \
-	range=2-4,except=222:333:444,shift=1,even="DS;%s",odd="I;%s/L01"
+	range=2-4,except=222:333:444,shift=1,even="DS;%s",odd="IU;%s/L01"
 
 ##
 ## Handle included sample dictionaries.
